..
      Copyright 2010-2011 United States Government as represented by the
      Administrator of the National Aeronautics and Space Administration.
      All Rights Reserved.

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

Fake Drivers
============

When the real thing isn't available and you have some development to do these
fake implementations of various drivers let you get on with your day.


The :mod:`fake_compute` Module
------------------------------

.. automodule:: manila.tests.fake_compute
    :noindex:
    :members:
    :undoc-members:
    :show-inheritance:


The :mod:`fake_driver` Module
-----------------------------

.. automodule:: manila.tests.fake_driver
    :noindex:
    :members:
    :undoc-members:
    :show-inheritance:


The :mod:`fake_network` Module
------------------------------

.. automodule:: manila.tests.fake_service_instance
    :noindex:
    :members:
    :undoc-members:
    :show-inheritance:


The :mod:`fake_utils` Module
----------------------------

.. automodule:: manila.tests.fake_utils
    :noindex:
    :members:
    :undoc-members:
    :show-inheritance:


The :mod:`fake_volume` Module
------------------------------

.. automodule:: manila.tests.fake_volume
    :noindex:
    :members:
    :undoc-members:
    :show-inheritance:
